@@ -24,18 +24,7 @@ class FieldEntry extends Entry implements FieldEntryInterface
 {
     private $field;
 
-    /**
-     * Constructor.
-     *
-     * @param int    $id
-     * @param string $field
-     * @param string $strategy
-     * @param int    $mask
-     * @param bool   $granting
-     * @param bool   $auditFailure
-     * @param bool   $auditSuccess
-     */
-    public function __construct($id, AclInterface $acl, $field, SecurityIdentityInterface $sid, $strategy, $mask, $granting, $auditFailure, $auditSuccess)
+    public function __construct(?int $id, AclInterface $acl, string $field, SecurityIdentityInterface $sid, string $strategy, int $mask, bool $granting, bool $auditFailure, $auditSuccess)
     {
         parent::__construct($id, $acl, $sid, $strategy, $mask, $granting, $auditFailure, $auditSuccess);
 
@@ -53,23 +42,18 @@ class FieldEntry extends Entry implements FieldEntryInterface
     /**
      * {@inheritdoc}
      */
-    public function serialize()
+    public function __serialize(): array
     {
-        return serialize([
-            $this->field,
-            parent::serialize(),
-        ]);
+        return [$this->field, parent::__serialize()];
     }
 
     /**
      * {@inheritdoc}
      */
-    public function unserialize($serialized)
+    public function __unserialize(array $data): void
     {
-        list($this->field, $parentStr) = unserialize($serialized);
-        if (!\is_string($parentStr)) {
-            throw new \BadMethodCallException('Cannot serialize '.__CLASS__);
-        }
-        parent::unserialize($parentStr);
+        [$this->field, $parentData] = $data;
+        $parentData = \is_array($parentData) ? $parentData : unserialize($parentData);
+        parent::__unserialize($parentData);
     }
 }
